translate.convert.po2mozlang

Package translate :: Package convert :: Module po2mozlang |
[hide private]
[frames] | no frames]

# Module po2mozlang

source code

convert Gettext PO localization files to Mozilla .lang files

see: http://translate.sourceforge.net/wiki/toolkit/po2mozlang for examples and usage instructions

Classes | [hide private]
| po2lang

Functions | [hide private]
convertlang(inputfile, outputfile, templates, includefuzzy=False) reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Variables | [hide private]
| formats = `{"po":("lang", convertlang), ("po", "lang"):("lang",`...``

Imports: lang, po

Variables Details | [hide private]

  ### formats Value:
      {"po":("lang", convertlang), ("po", "lang"):("lang", convertlang),}